@@ -106,6 +106,37 @@ sub create_url {
 
 ################################################################################
 
+=head1 check_href
+
+   C<href>  ,   ,     C<sid>  C<_salt>.  C<javascript>-    .
+
+=head2 
+
+
+	#  $options: {href => '/?type=foo&_x=1&id=1'}, sid = 666
+
+	check_href ($options);
+
+	#  $options: {href => '/?type=foo&_x=1&id=1&sid=666&_salt=0.357357387387'}
+
+
+=cut
+
+################################################################################
+
+sub check_href {
+
+	my ($options) = @_;
+	
+	if ($options -> {href} !~ /^(\#|java)/ and $options -> {href} !~ /\&sid=/) {	
+		$options -> {href} .= "\&sid=$_REQUEST{sid}";
+		$options -> {href} .= '&_salt=' . rand;
+	}	
+	
+}
+
+################################################################################
+
 =head1 draw_page
 
     .   ,    .
@@ -1097,4 +1128,16 @@ sub draw_calendar {
 	drawer_call ('draw_calendar', @_);
 }
 
+################################################################################
+
+sub draw_form_field_image {
+	drawer_call ('draw_form_field_image', @_);
+}
+
+################################################################################
+
+sub draw_form_field_htmleditor {
+	drawer_call ('draw_form_field_htmleditor', @_);
+}
+
 1;
